@@ -1,3 +1,5 @@
+import torch
+
 from kappadata.datasets.kd_dataset import KDDataset
 
 
@@ -9,14 +11,20 @@ class ClassificationDataset(KDDataset):
         self.classes = classes
 
     def getitem_x(self, idx, _=None):
-        return self.x[idx].clone()
+        x = self.x[idx]
+        if torch.is_tensor(x):
+            x = x.clone()
+        return x
 
     def getitem_class(self, idx, _=None):
         return self.classes[idx]
 
     @property
     def n_classes(self):
-        return max(self.classes).item() + 1
+        max_class = max(self.classes)
+        if torch.is_tensor(max_class):
+            max_class = max_class.item()
+        return max_class + 1
 
     def __len__(self):
         return len(self.classes)
